@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw(DateTime::Format::Natural::Compat);
 
-our $VERSION = '1.23';
+our $VERSION = '1.25';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -44,7 +44,7 @@ sub _daytime_in_the_variant
     $self->_register_trace;
     my $opts = pop;
     my ($hour) = @_;
-    $hour += $opts->{hours};
+    $hour += $opts->{hours} || 0;
     if ($self->_valid_time(hour => $hour)) {
         $self->_set(
             hour   => $hour,
@@ -103,16 +103,17 @@ sub _hourtime_variant
     my $self = shift;
     $self->_register_trace;
     my $opts = pop;
-    my ($hours, $when) = @_;
-    if ($self->_valid_time(hour => $opts->{hour})) {
+    my ($value, $when) = @_;
+    my $hours = $opts->{hours} || 0;
+    if ($self->_valid_time(hour => $hours)) {
         $self->_set(
-            hour   => $opts->{hour},
+            hour   => $hours,
             minute => 0,
         );
         $self->_add_or_subtract({
             when  => $when,
             unit  => 'hour',
-            value => $hours,
+            value => $value,
         });
     }
 }
@@ -377,6 +378,30 @@ sub _count_weekday_from_now
     );
 }
 
+sub _final_weekday_in_month
+{
+    my $self = shift;
+    $self->_register_trace;
+    my $opts = pop;
+    my ($wday, $month) = @_;
+    my $days = $self->_Days_in_Month($self->{datetime}->year, $month);
+    my ($year, $day);
+    ($year, $month, $day) = $self->_Nth_Weekday_of_Month_Year(
+        $self->{datetime}->year,
+        $month,
+        $wday,
+        1,
+    );
+    while ($day <= $days - 7) {
+        $day += 7;
+    }
+    $self->_set(
+        year  => $year,
+        month => $month,
+        day   => $day,
+    );
+}
+
 1;
 __END__
 
